<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3384"/>
        <source>Icon size</source>
        <translation>Icon size</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3392"/>
        <source>Auto merge</source>
        <translation>Auto merge</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3404"/>
        <source>Auto arrange</source>
        <translation>Auto arrange</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3441"/>
        <source>Corner Settings</source>
        <translation>Corner Settings</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3450"/>
        <location filename="../view/canvasgridview.cpp" line="3455"/>
        <source>Set Wallpaper</source>
        <translation>Set Wallpaper</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3453"/>
        <source>Wallpaper and Screensaver</source>
        <translation>Wallpaper and Screensaver</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3632"/>
        <source>Properties</source>
        <translation>Properties</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3432"/>
        <source>Display Settings</source>
        <translation>Display Settings</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="37"/>
        <source>Tiny</source>
        <translation>Tiny</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="38"/>
        <source>Small</source>
        <translation>Small</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="39"/>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="40"/>
        <source>Large</source>
        <translation>Large</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="41"/>
        <source>Super large</source>
        <translation>Super large</translation>
    </message>
</context>
<context>
    <name>DesktopMain</name>
    <message>
        <location filename="../main.cpp" line="169"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="725"/>
        <source>Wallpaper Slideshow</source>
        <translation>Wallpaper Slideshow</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="771"/>
        <source>When login</source>
        <translation>When login</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="773"/>
        <source>When wakeup</source>
        <translation>When wakeup</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="825"/>
        <source>Require a password on wakeup</source>
        <translation>Require a password on wakeup</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="857"/>
        <source>Never</source>
        <translation>Never</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="859"/>
        <source>Wait:</source>
        <translation>Wait:</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="892"/>
        <source>Wallpaper</source>
        <translation>Wallpaper</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="904"/>
        <source>Screensaver</source>
        <translation>Screensaver</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="969"/>
        <source>Loading wallpapers...</source>
        <translation>Loading wallpapers...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="971"/>
        <source>Loading screensavers...</source>
        <translation>Loading screensavers...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1028"/>
        <source>Desktop</source>
        <comment>button</comment>
        <translation>Desktop</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1029"/>
        <source>Lock Screen</source>
        <comment>button</comment>
        <translation>Lock Screen</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1030"/>
        <source>Both</source>
        <translation>Both</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1105"/>
        <source>Apply</source>
        <comment>button</comment>
        <translation>Apply</translation>
    </message>
</context>
<context>
    <name>WaterMaskFrame</name>
    <message>
        <location filename="../view/watermaskframe.cpp" line="390"/>
        <location filename="../view/watermaskframe.cpp" line="391"/>
        <source>Not authorized</source>
        <translation>Not authorized</translation>
    </message>
    <message>
        <location filename="../view/watermaskframe.cpp" line="401"/>
        <location filename="../view/watermaskframe.cpp" line="402"/>
        <source>In trial period</source>
        <translation>In trial period</translation>
    </message>
</context>
</TS>